pub enum RemediationLevel {
Unavailable,
Workaround,
TemporaryFix,
OfficialFix,
}Expand description
The Remediation Level field as defined by the CVSS specification.
“Not Defined” is considered the same as a missing value. This is done by setting TemporalVector.remediation_level to None.
Variants
Unavailable (“RL:U”) value for the Remediation Level field.
Workaround
Workaround (“RL:W”) value for the Remediation Level field.
TemporaryFix
Temporary Fix (“RL:T”) value for the Remediation Level field.
OfficialFix
Official Fix (“RL:O”) value for the Remediation Level field.
Implementations
Sourceimpl RemediationLevel
impl RemediationLevel
Sourcepub fn numerical_value(&self) -> f64
pub fn numerical_value(&self) -> f64
Provides the numerical value associated with the metric, as specified by the CVSS specification.
In normal usage you should not need to call this yourself.