pub enum AttackComplexity {
Low,
High,
}Expand description
The Attack Complexity field as defined by the CVSS specification.
Variants
Low
Low (“AC:L”) value for the Attack Complexity field.
High
High (“AC:H”) value for the Attack Complexity field.
Implementations
Sourceimpl AttackComplexity
impl AttackComplexity
Sourcepub fn numerical_value(&self) -> f64
pub fn numerical_value(&self) -> f64
Provides the numerical value associated with the metric, as specified by the CVSS specification.
In normal usage you should not need to call this yourself.